@@ -1,6 +1,6 @@
 # this is the API of GDAPS itself.
-import logging
 import typing
+import warnings
 
 from django.apps import AppConfig
 
@@ -26,7 +26,7 @@ class PluginMeta:
                 verbose_name = _('Foo Plugin')
                 author = 'Me Personally'
                 description = _('A foo plugin')
-                visible = True
+                hidden = false
                 version = '1.0.0'
                 compatibility = "myproject.core>=2.3.0"
 
@@ -54,13 +54,7 @@ class PluginMeta:
     #: This can be used in your application to group plugins.
     category = "GDAPS"
 
-    #: A boolean value whether the plugin should be visible, or hidden.
-    #:
-    #:     .. deprecated:: 0.4.2
-    #:         Use `hidden` instead.
-    visible = True
-
-    #:A boolean value whether the plugin should be hidden, or visible. False by default.
+    #:A boolean value whether the plugin should be hidden. False by default.
     hidden = False
 
     #: A string containing one or more other plugins that this plugin is known being compatible with, e.g.
@@ -101,9 +95,6 @@ class PluginConfig(AppConfig):
     PluginMeta: PluginMeta = None
 
 
-logger = logging.getLogger(__name__)
-
-
 class InterfaceMeta(type):
     """Metaclass of Interfaces and Implementations
 
@@ -123,7 +114,7 @@ class InterfaceMeta(type):
             mcs.__interface__ = True
             InterfaceRegistry.append(mcs)
             if not mcs.__name__.startswith("I"):
-                logger.warning(
+                warnings.warn(
                     f"WARNING: <{mcs.__name__}>: Interface names should start with a capital 'I'."
                 )
         else:
@@ -148,24 +139,32 @@ class InterfaceMeta(type):
 
     def __iter__(mcs) -> typing.Iterable:
         """Returns an object with all enabled plugins, where you can iterate over."""
-        return iter(
-            # return only enabled plugins
-            impl
-            for impl in mcs._implementations
-            if getattr(impl, "enabled", True)
-        )
+
+        def by_weight(element):
+            return getattr(element, "weight", 0)
+
+        # return only enabled plugins
+        plugin_list = [
+            impl for impl in mcs._implementations if getattr(impl, "enabled", True)
+        ]
+        # if weight attribute is available, sort list by weight
+        plugin_list.sort(key=by_weight)
+        return iter(plugin_list)
 
     def all_plugins(mcs) -> typing.Iterable:
         """Returns all plugins, even if they are not enabled."""
-        logger.warning(
-            f"<Interface>.plugins() is deprecated. Please iterate directly over {mcs.__name}."
+        warnings.warn(
+            f"<Interface>.plugins() is deprecated. Please iterate directly over {mcs.__name}.",
+            DeprecationWarning,
         )
         return mcs._implementations
 
     def plugins(mcs) -> typing.Iterable:
         """Returns all plugins, even if they are not enabled."""
-        logger.warning(
-            f"<Interface>.plugins() is deprecated and will be removed. Please iterate directly over the {mcs.__name__} class."
+        warnings.warn(
+            f"<Interface>.plugins() is deprecated and will be removed. Please iterate directly over the "
+            f"{mcs.__name__} class.",
+            DeprecationWarning,
         )
         return mcs.__iter__()
 
@@ -254,7 +253,7 @@ class InterfaceRegistry:
     :class:`gdaps.templatetags.gdaps`.
     """
 
-    _interfaces = []
+    _interfaces:list[Interface] = []
 
     @classmethod
     def append(cls, interface) -> None:
@@ -264,7 +263,7 @@ class InterfaceRegistry:
     def get(cls, item: str) -> typing.Iterable:
         for interface in cls._interfaces:
             if interface.__name__ == item:
-                return iter(interface)
+                return interface
         raise InterfaceNotFound(
             f"'{item}' was not found. Did you register it with the '@Interface' "
             f"decorator?"
