@@ -9,15 +9,31 @@ class InterfaceNotFound(Exception):
 
 
 class ITemplatePluginMixin:
-    """A mixin that be inherited from to build renderable plugins.
+    """A mixin that can be inherited from to build renderable plugins.
 
-    Use this in conjunction with the :ref:`render_plugin templatetag <template-support>`
-    to build plugins that are renderable in templates.
+    Create an interface that inherits from ITemplatePluginMixin. Each
+    implementation must either have a `template` (direct string HTML template,
+    for short ones) or `template_name` (which points to the template to render).
+
+    You can add fixed `context`, or override `get_plugin_context` which receives
+    the context of the view the plugin is rendered in.
+
+    In your template, use
+    ```
+    {% load gdaps %}
+    <ul class="alerts">
+    {% render_plugin IMyListItem %}
+    </ul>
+    ```
+    in your template anywhere, and all of your implementations are rendered,
+    one after each other, in a line. Each plugin can come from another app.
+    You can change the order of the rendering using the `weight` attribute.
     """
 
     template: str = ""
     template_name: str = ""
     context: dict = {}
+    weight = 0
 
     def get_plugin_context(self, context: Context) -> Context:
         """Override this method to add custom context to the plugin.
