@@ -12,8 +12,8 @@ class GdapsPlugin(models.Model):
     version = models.CharField(max_length=32, default="1.0.0")
     compatibility = models.CharField(max_length=255, null=True, default=None)
     category = models.CharField(max_length=255, blank=True, default="")
-    visible = models.BooleanField(default=True)
     enabled = models.BooleanField(default=True)
+    hidden = models.BooleanField(default=False)
 
     def __str__(self):
         return self.verbose_name
