@@ -23,7 +23,7 @@ def test_plugin_meta():
 
 @pytest.mark.django_db
 def test_plugin_initialize_cmd():
-    from gdaps.core.models import GdapsPlugin
+    from gdaps.models import GdapsPlugin
 
     # first, no plugins are installed.
     with pytest.raises(ObjectDoesNotExist):
